==> com.deepin.gomoku_1.0.8.orig.tar.xz: com.deepin.gomoku-1.0.8/translations/deepin-gomoku_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>BTMusicControl</name>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btmusiccontrol.cpp" line="90"/>
        <source>Sound Off</source>
        <translation>Pa Tinguj</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btmusiccontrol.cpp" line="94"/>
        <source>Sound On</source>
        <translation>Me Tinguj</translation>
    </message>
</context>
<context>
    <name>BTReplay</name>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btreplay.cpp" line="99"/>
        <source>New Game</source>
        <translation>Lojë e Re</translation>
    </message>
</context>
<context>
    <name>BTStartPause</name>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="123"/>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="160"/>
        <source>Start</source>
        <translation>Nise</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="165"/>
        <source>Continue</source>
        <translation>Vazhdoje</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="169"/>
        <source>Pause</source>
        <translation>Ndalesë</translation>
    </message>
</context>
<context>
    <name>Buttonagain</name>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/buttonagain.cpp" line="136"/>
        <source>Play Again</source>
        <translation>Luani Sërish</translation>
    </message>
</context>
<context>
    <name>Buttonrest</name>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/buttonrest.cpp" line="157"/>
        <source>Have a Rest</source>
        <translation>Bëni një Pushim</translation>
    </message>
</context>
<context>
    <name>CancelButton</name>
    <message>
        <location filename="../gomoku/src/widget/exitdialog/cancelbutton.cpp" line="120"/>
        <source>Keep Playing</source>
        <translation>Vazhdoni të Luani</translation>
    </message>
</context>
<context>
    <name>Determinebutton</name>
    <message>
        <location filename="../gomoku/src/widget/selectchess/determinebutton.cpp" line="114"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ExitButton</name>
    <message>
        <location filename="../gomoku/src/widget/exitdialog/exitbutton.cpp" line="117"/>
        <source>Exit</source>
        <translation>Dalje</translation>
    </message>
</context>
<context>
    <name>ExitLabel</name>
    <message>
        <location filename="../gomoku/src/widget/exitdialog/exitlabel.cpp" line="30"/>
        <source>Are you sure you want to exit the game?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GomokuWindow</name>
    <message>
        <location filename="../gomoku/src/main.cpp" line="63"/>
        <location filename="../gomoku/src/main.cpp" line="64"/>
        <source>Gomoku</source>
        <translation>Gomoku</translation>
    </message>
    <message>
        <location filename="../gomoku/src/main.cpp" line="65"/>
        <source>Gomoku is a small chess game for two players.</source>
        <translation>Gomoku është një lojë e vockël shahu me dy lojtarë.</translation>
    </message>
</context>
<context>
    <name>PlayingScreen</name>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="124"/>
        <source>I am thinking...</source>
        <translation>Po mendohem…</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="127"/>
        <source>Place your chess piece...</source>
        <translation>Vini gurin tuaj të shahut…</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="201"/>
        <source>Welcome</source>
        <translation>Mirë se vini!</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="110"/>
        <source>Game Over!</source>
        <translation>Loja Përfundoi!</translation>
    </message>
</context>
<context>
    <name>Resultinfo</name>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/resultinfo.cpp" line="46"/>
        <source>You did great!</source>
        <translation>Dolët shumë mirë!</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/resultinfo.cpp" line="48"/>
        <source>Game Over</source>
        <translation>Loja Përfundoi</translation>
    </message>
</context>
<context>
    <name>Selectinfo</name>
    <message>
        <location filename="../gomoku/src/widget/selectchess/selectinfo.cpp" line="47"/>
        <source>Play as</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> com.deepin.gomoku_1.0.10.orig.tar.xz: com.deepin.gomoku-1.0.10/translations/deepin-gomoku_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>BTMusicControl</name>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btmusiccontrol.cpp" line="90"/>
        <source>Sound Off</source>
        <translation>Pa Tinguj</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btmusiccontrol.cpp" line="94"/>
        <source>Sound On</source>
        <translation>Me Tinguj</translation>
    </message>
</context>
<context>
    <name>BTReplay</name>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btreplay.cpp" line="99"/>
        <source>New Game</source>
        <translation>Lojë e Re</translation>
    </message>
</context>
<context>
    <name>BTStartPause</name>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="123"/>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="160"/>
        <source>Start</source>
        <translation>Nise</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="165"/>
        <source>Continue</source>
        <translation>Vazhdoje</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/buttonfunction/btstartpause.cpp" line="169"/>
        <source>Pause</source>
        <translation>Ndalesë</translation>
    </message>
</context>
<context>
    <name>Buttonagain</name>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/buttonagain.cpp" line="136"/>
        <source>Play Again</source>
        <translation>Luani Sërish</translation>
    </message>
</context>
<context>
    <name>Buttonrest</name>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/buttonrest.cpp" line="157"/>
        <source>Have a Rest</source>
        <translation>Bëni një Pushim</translation>
    </message>
</context>
<context>
    <name>CancelButton</name>
    <message>
        <location filename="../gomoku/src/widget/exitdialog/cancelbutton.cpp" line="120"/>
        <source>Keep Playing</source>
        <translation>Vazhdoni të Luani</translation>
    </message>
</context>
<context>
    <name>Determinebutton</name>
    <message>
        <location filename="../gomoku/src/widget/selectchess/determinebutton.cpp" line="114"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ExitButton</name>
    <message>
        <location filename="../gomoku/src/widget/exitdialog/exitbutton.cpp" line="117"/>
        <source>Exit</source>
        <translation>Dalje</translation>
    </message>
</context>
<context>
    <name>ExitLabel</name>
    <message>
        <location filename="../gomoku/src/widget/exitdialog/exitlabel.cpp" line="30"/>
        <source>Are you sure you want to exit the game?</source>
        <translation>Jeni i sigurt se doni të dilet nga loja?</translation>
    </message>
</context>
<context>
    <name>GomokuWindow</name>
    <message>
        <location filename="../gomoku/src/main.cpp" line="63"/>
        <location filename="../gomoku/src/main.cpp" line="64"/>
        <source>Gomoku</source>
        <translation>Gomoku</translation>
    </message>
    <message>
        <location filename="../gomoku/src/main.cpp" line="65"/>
        <source>Gomoku is a small chess game for two players.</source>
        <translation>Gomoku është një lojë e vockël shahu me dy lojtarë.</translation>
    </message>
</context>
<context>
    <name>PlayingScreen</name>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="124"/>
        <source>I am thinking...</source>
        <translation>Po mendohem…</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="127"/>
        <source>Place your chess piece...</source>
        <translation>Vini gurin tuaj të shahut…</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="201"/>
        <source>Welcome</source>
        <translation>Mirë se vini!</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/playingscreen/playingscreen.cpp" line="110"/>
        <source>Game Over!</source>
        <translation>Loja Përfundoi!</translation>
    </message>
</context>
<context>
    <name>Resultinfo</name>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/resultinfo.cpp" line="46"/>
        <source>You did great!</source>
        <translation>Dolët shumë mirë!</translation>
    </message>
    <message>
        <location filename="../gomoku/src/widget/resultpopup/resultinfo.cpp" line="48"/>
        <source>Game Over</source>
        <translation>Loja Përfundoi</translation>
    </message>
</context>
<context>
    <name>Selectinfo</name>
    <message>
        <location filename="../gomoku/src/widget/selectchess/selectinfo.cpp" line="47"/>
        <source>Play as</source>
        <translation>Luani si</translation>
    </message>
</context>
</TS>
